VimError

Enum VimError 

pub enum VimError {
    NoFileName,
    NoPreviousRegularExpression,
    NoWriteSinceLastChange,
    CantOpenFileForWriting,
    PatternNotFound,
    NotAnEditorCommand,
}
Vim-compatible errors shown on the command/status line.

Variants



NoFileName

A write command has no file name to write to.



NoPreviousRegularExpression

No previous search pattern exists for a repeat or empty search.



NoWriteSinceLastChange

The buffer has unsaved changes and quit was not forced.



CantOpenFileForWriting

A write command could not open the file for writing.



PatternNotFound

The submitted search pattern was not found.



NotAnEditorCommand

The submitted : command is not supported.

Implementations

Source

impl VimError

pub const fn code(self) -> &'static str

Returns the canonical Vim error code.

pub const fn message(self) -> &'static str

Returns the canonical short Vim error text.

pub fn status_text(self) -> String

Renders the error for the Vim command/status line.