pub struct PluginHostOwnerBatches { /* private fields */ }Expand description
Successful-return work that must be published by non-runtime owners.
Implementations
Sourceimpl PluginHostOwnerBatches
impl PluginHostOwnerBatches
Sourcepub const fn identity_proof(&self) -> &PluginIdentity
pub const fn identity_proof(&self) -> &PluginIdentity
Returns the identity proof shared by owner-published work.
Sourcepub const fn effects(&self) -> &SealedPluginEffectBatch
pub const fn effects(&self) -> &SealedPluginEffectBatch
Returns the unpublished editor effects.
Sourcepub const fn workspace_io(&self) -> &SealedPluginWorkspaceIoBatch
pub const fn workspace_io(&self) -> &SealedPluginWorkspaceIoBatch
Returns the unpublished workspace I/O.
Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Returns whether the paired owner work is an empty scheduler no-op.
Sourcepub fn discard(self) -> PluginHostOwnerDiscardReport
pub fn discard(self) -> PluginHostOwnerDiscardReport
Discards paired owner work that will not be retried.
Sourcepub fn into_parts(self) -> PluginHostOwnerBatchesParts
pub fn into_parts(self) -> PluginHostOwnerBatchesParts
Splits owner-published work by owning queue.