pub enum VimError {
NoFileName,
NoPreviousRegularExpression,
NoWriteSinceLastChange,
CantOpenFileForWriting,
PatternNotFound,
NotAnEditorCommand,
}Expand description
Vim-compatible errors shown on the command/status line.
Variants
NoFileName
A write command has no file name to write to.
NoPreviousRegularExpression
No previous search pattern exists for a repeat or empty search.
NoWriteSinceLastChange
The buffer has unsaved changes and quit was not forced.
CantOpenFileForWriting
A write command could not open the file for writing.
PatternNotFound
The submitted search pattern was not found.
NotAnEditorCommand
The submitted : command is not supported.
Implementations