pub struct CapabilitySet { /* private fields */ }Expand description
Composable plugin capability set used for authorization decisions.
Implementations
Sourceimpl CapabilitySet
impl CapabilitySet
Sourcepub fn intersection(&self, requested: &Self) -> Self
pub fn intersection(&self, requested: &Self) -> Self
Returns the granted intersection of two capability sets.
Sourcepub fn allows(&self, capability: PluginCapabilityRef<'_>) -> bool
pub fn allows(&self, capability: PluginCapabilityRef<'_>) -> bool
Returns whether this set authorizes one host-import query.
Sourcepub fn is_subset_of(&self, other: &Self) -> bool
pub fn is_subset_of(&self, other: &Self) -> bool
Returns whether every authority in this set is also present in other.
Sourcepub fn into_capabilities(self) -> PluginCapabilities
pub fn into_capabilities(self) -> PluginCapabilities
Converts this set back to the current serialized capability DTO.